@@ -4,7 +4,7 @@ from autocorrect import Speller
 import re
 import os
 import traceback
-from .utils import *
+from utils import *
 from functools import partial
 
 class pdfextracter:
@@ -18,6 +18,8 @@ class pdfextracter:
                         self.textpages=self.extract_pdf_text(pdf_path,password=pdf_password,pages=pages,crop=(left_most_x,left_most_y,right_most_x,right_most_y)) 
                         # allpagecleaned=list(map(clean_text,textpages))
                         self.allpagecleaned=[self.clean_pdf_text(i) for i in self.textpages]
+                        print("self.allpagecleaned")
+                        print(self.allpagecleaned)
                         return self.allpagecleaned
                 else:
                     raise InvalidFileFormat("We only support .pdf or .PDF",os.path.splitext(pdf_path)[-1])
@@ -81,14 +83,20 @@ class pdfextracter:
             if i1.strip()!="":
                 new_string = i1.encode('ascii',errors='ignore').decode()
                 self.j.append(new_string.strip())
-        cleanedlines=list(map(partial(clean, stemming=False,stopwords=False,clean_all=False),self.j))
+        print("JJJ")
+        print(self.j)
+        self.cleanedlines=list(map(partial(clean, stemming=False,stopwords=False,clean_all=False),self.j))
+        print("cleanedlines")
+        print(self.cleanedlines)
         self.spell = Speller(lang='en',fast=True,only_replacements=True)
         self.outputcleanedlines=[]
-        for i in cleanedlines:
+        for i in self.cleanedlines:
             sen=re.sub("[^a-zA-Z0-9 ][@_!#$%^&*()<>?/\|}{~:]", "",self.spell(i))
             # sen=spell(i)
             if len(sen)>3:
                 self.outputcleanedlines.append(sen)
+        print("outputcleanedlines")
+        print(self.outputcleanedlines)
         return self.outputcleanedlines
 
 
@@ -96,5 +104,7 @@ class pdfextracter:
 
 
 
-
-
+if __name__=="__main__":
+    pdfpath=r"../../../Beginning Interviewing.pdf"
+    j=pdfextracter()
+    print(j.get_pdf_text(pdfpath))
